summaryrefslogtreecommitdiffhomepage
path: root/dev/lib/logic/math.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'dev/lib/logic/math.hpp')
-rw-r--r--dev/lib/logic/math.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/dev/lib/logic/math.hpp b/dev/lib/logic/math.hpp
index cab995a..e796eae 100644
--- a/dev/lib/logic/math.hpp
+++ b/dev/lib/logic/math.hpp
@@ -1,7 +1,7 @@
/*
* File: math.hpp
* Purpose: Mathematics c++ header.
- * Author: Amlal El Mahrouss (founder@snu.systems)
+ * Author: Amlal El Mahrouss (amlal@nekernel.org)
* Copyright 2025, Amlal El Mahrouss.
*/
@@ -9,7 +9,7 @@
#include <cmath>
-namespace snu::math
+namespace ocl
{
template <std::size_t T>
struct is_non_boolean_integer final
@@ -32,4 +32,4 @@ namespace snu::math
constexpr inline auto not_a_number = NAN;
constexpr inline auto positive_infinity = INFINITY;
constexpr inline auto negative_infinity = -positive_infinity;
-} // namespace snu::math \ No newline at end of file
+} // namespace ocl \ No newline at end of file